@@ -19,8 +19,12 @@ my $filter = MIDI::RtController::Filter::CC->new(rtc => $control);
 
 # $control->add_filter('breathe', ['all'], $filter->curry::breathe);
 
-$filter->time_step(500_000);
-$control->add_filter('scatter', ['all'], $filter->curry::scatter);
+# $filter->time_step(500_000);
+# $control->add_filter('scatter', ['all'], $filter->curry::scatter);
+
+$filter->step_up(10);
+$filter->step_down(2);
+$control->add_filter('stair_step', ['all'], $filter->curry::stair_step);
 
 $control->run;
 
