@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use v5.36;
 
@@ -38,6 +38,13 @@ has control => (
 );
 
 
+has initial_point => (
+    is      => 'rw',
+    isa     => Velocity, # no CC# msg value in Types::MIDI yet
+    default => 0,
+);
+
+
 has range_bottom => (
     is      => 'rw',
     isa     => Num,
@@ -66,6 +73,20 @@ has time_step => (
 );
 
 
+has step_up => (
+    is      => 'rw',
+    isa     => Num,
+    default => 2,
+);
+
+
+has step_down => (
+    is      => 'rw',
+    isa     => Num,
+    default => 1,
+);
+
+
 has running => (
     is      => 'rw',
     isa     => Bool,
@@ -111,12 +132,63 @@ sub scatter ($self, $device, $dt, $event) {
 
     $self->running(1);
 
-    my @values = (0 .. 127);
+    my $value  = $self->initial_point;
+    my @values = ($self->range_bottom .. $self->range_top);
 
     while (!$self->stop) {
-        my $value = $values[ int rand @values ];
         my $cc = [ 'control_change', $self->channel, $self->control, $value ];
         $self->rtc->send_it($cc);
+        $value = $values[ int rand @values ];
+        usleep $self->time_step;
+    }
+
+    return 0;
+}
+
+
+sub stair_step ($self, $device, $dt, $event) {
+    return 0 if $self->running;
+
+    my ($ev, $chan, $ctl, $val) = $event->@*;
+
+    $self->running(1);
+
+    my $value  = $self->initial_point;
+    my @values = ($self->range_bottom .. $self->range_top);
+
+    my $direction = 1; # up
+
+    my $up   = $self->step_up;
+    my $down = $self->step_down;
+
+    while (!$self->stop) {
+        my $cc = [ 'control_change', $self->channel, $self->control, $value ];
+        $self->rtc->send_it($cc);
+
+        if ($direction) {
+            $value = ($value + $self->step_up) < $self->range_top ? $value + $self->step_up
+                                                                  : $self->range_top;
+        }
+        else {
+            $value = ($value - $self->step_down) > $self->range_bottom ? $value - $self->step_down
+                                                                       : $self->range_bottom;
+        }
+
+        # toggle the stair-step direction
+        $direction = !$direction;
+
+        # flip up to down and vice-versa
+        if ($value >= $self->range_top) {
+            $value = $self->range_top;
+            $self->step_up(-$up);
+            $self->step_down(-$down);
+        }
+        if ($value <= $self->range_bottom) {
+            $value = $self->range_bottom;
+            $self->step_up($up);
+            $self->step_down($down);
+        }
+
         usleep $self->time_step;
     }
 
@@ -137,7 +209,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -174,6 +246,7 @@ All filter methods must accept the object, a MIDI device name, a
 delta-time, and a MIDI event ARRAY reference, like:
 
   sub breathe ($self, $device, $delta, $event) {
+    return 0 if $self->running;
     my ($event_type, $chan, $control, $value) = $event->@*;
     ...
     return $boolean;
@@ -210,6 +283,16 @@ Return or set the control change number between C<0> and C<127>.
 
 Default: C<1> (mod-wheel)
 
+=head2 initial_point
+
+  $initial_point = $filter->initial_point;
+  $filter->initial_point($number);
+
+Return or set the control change initial point number between C<0> and
+C<127>.
+
+Default: C<0>
+
 =head2 range_bottom
 
   $range_bottom = $filter->range_bottom;
@@ -248,6 +331,24 @@ C<1,000,000> = C<1> second).
 
 Default: C<250_000> (a quarter of a second)
 
+=head2 step_up
+
+  $step_up = $filter->step_up;
+  $filter->step_up($number);
+
+The current iteration upward step.
+
+Default: C<2>
+
+=head2 step_down
+
+  $step_down = $filter->step_down;
+  $filter->step_down($number);
+
+The current iteration downward step.
+
+Default: C<1>
+
 =head2 running
 
   $running = $filter->running;
@@ -298,8 +399,22 @@ until B<stop> is seen.
 Passing C<all> means that any MIDI event will cause this filter to be
 triggered.
 
+=head2 stair_step
+
+  $control->add_filter('stair_step', all => $filter->curry::stair_step);
+
+This filter sets the B<running> flag, chooses a number starting at the
+B<initial_point>, adds B<step_up> or subtracts B<step_down>
+successively, sending that value as a B<control> change message, over
+the MIDI B<channel>, every iteration, until B<stop> is seen.
+
+Passing C<all> means that any MIDI event will cause this filter to be
+triggered.
+
 =head1 SEE ALSO
 
+The F<eg/*.pl> program(s) in this distribution
+
 L<Iterator::Breathe>
 
 L<Moo>
